
import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def HostVirtualNic(vim, *args, **kwargs):
    '''This data object type describes a virtual network adapter representing an
    adapter that connects to a virtual switch. A VirtualNic differs from a
    PhysicalNic in that the latter corresponds to a physical device that is
    connected to the physical network. The former is a virtual device that is
    connected to a virtual switch. A VirtualNic accesses the external network
    through a virtual switch that is bridged through a PhysicalNic to a physical
    network.'''

    obj = vim.client.factory.create('{urn:vim25}HostVirtualNic')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 4:
        raise IndexError('Expected at least 5 arguments got: %d' % len(args))

    required = [ 'device', 'key', 'portgroup', 'spec' ]
    optional = [ 'port', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def MetricAlarmExpression(vim, *args, **kwargs):
    '''An alarm expression that uses a metric as the condition that triggers an alarm.
    Base type.There are two alarm operands: yellow and red. At least one of them
    must be set. The value of the alarm expression is determined as follows:'''

    obj = vim.client.factory.create('{urn:vim25}MetricAlarmExpression')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 3:
        raise IndexError('Expected at least 4 arguments got: %d' % len(args))

    required = [ 'metric', 'operator', 'type' ]
    optional = [ 'red', 'redInterval', 'yellow', 'yellowInterval', 'dynamicProperty',
        'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def AlarmTriggeringAction(vim, *args, **kwargs):
    '''This data object type describes one or more triggering transitions and an
    action to be done when an alarm is triggered.There are four triggering
    transitions; at least one of them must be provided. A gray state is considered
    the same as a green state, for the purpose of detecting transitions.'''

    obj = vim.client.factory.create('{urn:vim25}AlarmTriggeringAction')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 5:
        raise IndexError('Expected at least 6 arguments got: %d' % len(args))

    required = [ 'action', 'green2yellow', 'red2yellow', 'yellow2green', 'yellow2red' ]
    optional = [ 'transitionSpecs', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def OptionDef(vim, *args, **kwargs):
    '''Describes a user-defined option. The name of each option is identified by the
    "key" property, inherited from the ElementDescription data object type. You can
    indicate the property's position in a hierarchy by using a dot-separated
    notation. The string preceding the first dot is the top of the hierarchy. The
    hierarchy descends to a new sublevel with each dot. For example,
    "Ethernet.NetworkConnection.Bridged".'''

    obj = vim.client.factory.create('{urn:vim25}OptionDef')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 4:
        raise IndexError('Expected at least 5 arguments got: %d' % len(args))

    required = [ 'optionType', 'key', 'label', 'summary' ]
    optional = [ 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def VirtualDiskFlatVer2BackingOption(vim, *args, **kwargs):
    '''This data object type contains the available options when backing a virtual
    disk using a host file with the flat file format used in VMware Server and in
    ESX Server 2.x and greater. Flat disks are pre-allocated, whereas sparse disks
    are grown as needed.'''

    obj = vim.client.factory.create('{urn:vim25}VirtualDiskFlatVer2BackingOption')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 10:
        raise IndexError('Expected at least 11 arguments got: %d' % len(args))

    required = [ 'deltaDiskFormat', 'diskMode', 'eagerlyScrub', 'growable', 'hotGrowable',
        'split', 'thinProvisioned', 'uuid', 'writeThrough', 'type' ]
    optional = [ 'fileNameExtensions', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def VmPodConfigForPlacement(vim, *args, **kwargs):
    '''Initial VM configuration for the specified pod. This configuration will be
    saved to the pod config StorageDrsConfigInfo when the placement recommendations
    are applied.NOTE: This data object type and all of its methods are experimental
    and subject to change in future releases.'''

    obj = vim.client.factory.create('{urn:vim25}VmPodConfigForPlacement')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 1:
        raise IndexError('Expected at least 2 arguments got: %d' % len(args))

    required = [ 'storagePod' ]
    optional = [ 'disk', 'interVmRule', 'vmConfig', 'dynamicProperty', 'dynamicType' ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj




import logging
from pyvisdk.exceptions import InvalidArgumentError

########################################
# Automatically generated, do not edit.
########################################

log = logging.getLogger(__name__)

def VAppPropertyFault(vim, *args, **kwargs):
    '''The base fault for all vApp property configuration issues'''

    obj = vim.client.factory.create('{urn:vim25}VAppPropertyFault')

    # do some validation checking...
    if (len(args) + len(kwargs)) < 9:
        raise IndexError('Expected at least 10 arguments got: %d' % len(args))

    required = [ 'category', 'id', 'label', 'type', 'value', 'dynamicProperty', 'dynamicType',
        'faultCause', 'faultMessage' ]
    optional = [  ]

    for name, arg in zip(required+optional, args):
        setattr(obj, name, arg)

    for name, value in kwargs.items():
        if name in required + optional:
            setattr(obj, name, value)
        else:
            raise InvalidArgumentError("Invalid argument: %s.  Expected one of %s" % (name, ", ".join(required + optional)))

    return obj
